==> nocc-1.9.5.txz: usr/local/www/nocc/lang/fr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fr.php 2621 2014-06-23 12:43:39Z siebrand $
 */
/** French (français)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Gomoko
 * @author Hashar
 * @author IAlex
 * @author Od1n
 * @author Peter17
 * @author Sherbrooke
 * @author Verdy p
 */

$lang_locale = 'fr_FR.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Vous n\'avez pas saisi de nom d\'utilisateur';
$err_passwd_empty = 'Vous n\'avez pas saisi de mot de passe';
$alt_delete = 'Effacer les messages sélectionnés';
$alt_delete_one = 'Effacer le message';
$alt_new_msg = 'Nouveaux messages';
$alt_reply = 'Répondre à l\'auteur';
$alt_reply_all = 'Répondre à tous';
$alt_forward = 'Transférer';
$alt_next = 'Suivant';
$alt_prev = 'Précédent';
$title_next_page = 'Page suivante';
$title_prev_page = 'Page précédente';
$title_next_msg = 'Message suivant';
$title_prev_msg = 'Message précédent';
$html_theme_label = 'Thème :';
$html_welcome = 'Bienvenue à %1$s';
$html_login = 'Se connecter';
$html_user_label = 'Utilisateur :';
$html_passwd_label = 'Mot de passe :';
$html_submit = 'Soumettre';
$html_help = 'Aide';
$html_server_label = 'Serveur :';
$html_wrong = 'L\'identifiant ou le mot de passe ne sont pas valides';
$html_retry = 'Réessayer';
$html_remember = 'Conserver les paramètres';
$html_lang_label = 'Langue :';
$html_msgperpage_label = 'Messages par page :';
$html_preferences = 'Préférences';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adresse de courriel :';
$html_bccself = 'Recevoir une copie cachée';
$html_hide_addresses = 'Cacher les adresses e-mail';
$html_outlook_quoting = 'Citation à la Outlook';
$html_reply_to = 'Répondre à';
$html_reply_to_label = 'Répondre à:';
$html_use_signature = 'Utiliser la signature';
$html_signature = 'Signature';
$html_signature_label = 'Signature :';
$html_reply_leadin_label = 'Entête de réponse :';
$html_prefs_updated = 'Préférences mises à jour';
$html_manage_folders_link = 'Gestion des dossiers IMAP';
$html_manage_filters_link = 'Gestion des filtres e-mail';
$html_use_graphical_smilies = 'Utiliser les émoticones graphiques';
$html_sent_folder_label = 'Copier les éléments envoyés dans un dossier dédié :';
$html_trash_folder_label = 'Déplacer les éléments effacés dans un dossier dédié :';
$html_colored_quotes = 'Citations colorées';
$html_display_struct = 'Afficher le texte structuré';
$html_send_html_mail = 'Envoyer les courriels au format HTML';
$html_folders = 'Dossiers';
$html_folders_create_failed = 'Le dossier n\'a pas pu être créé !';
$html_folders_sub_failed = 'Impossible de s\'inscrire au dossier !';
$html_folders_unsub_failed = 'Impossible de se désinscrire du dossier !';
$html_folders_rename_failed = 'Le dossier n\'a pas pu être renommé !';
$html_folders_updated = 'Dossiers mis à jour';
$html_folder_subscribe = 'S\'inscrire à';
$html_folder_rename = 'Renommer';
$html_folder_create = 'Créer un nouveau dossier';
$html_folder_remove = 'Se désinscrire de';
$html_folder_delete = 'Supprimer';
$html_folder_to = 'vers';
$html_filter_remove = 'Supprimer';
$html_filter_body = 'Corps du message';
$html_filter_subject = 'Objet';
$html_filter_to = 'A';
$html_filter_cc = 'Cc';
$html_filter_from = 'De';
$html_filter_change_tip = 'Pour changer un filtre, réécrivez dessus.';
$html_reapply_filters = 'Réappliquer tous les filtres';
$html_filter_contains = 'contient';
$html_filter_name = 'Nom du filtre';
$html_filter_action = 'Action';
$html_filter_moveto = 'déplacer vers';
$html_select_one = '--Sélectionner--';
$html_and = 'Et';
$html_new_msg_in = 'Nouveaux messages dans';
$html_or = 'ou';
$html_move = 'Déplacer';
$html_copy = 'Copier';
$html_messages_to = 'le message sélectionné vers';
$html_gotopage = 'Aller à la page';
$html_gotofolder = 'Aller au dossier';
$html_other_folders = 'Liste des dossiers';
$html_page = 'Page';
$html_of = 'sur';
$html_view_header = 'Voir l\'entête';
$html_remove_header = 'Masquer l\'entête';
$html_inbox = 'Boîte de réception';
$html_new_msg = 'Ecrire';
$html_reply = 'Répondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Répondre à tous';
$html_forward = 'Transférer';
$html_forward_short = 'Tr :';
$html_forward_info = 'Le message transféré sera envoyé en pièce jointe avec ce message.';
$html_delete = 'Supprimer';
$html_new = 'Nouveau';
$html_mark = 'Effacer';
$html_att_label = 'Pièce jointe :';
$html_atts_label = 'Pièces jointes :';
$html_unknown = '[inconnu]';
$html_part_x = 'Partie %s';
$html_attach = 'Attacher';
$html_attach_forget = 'Vous devez attacher votre fichier avant d\'envoyer votre message !';
$html_attach_delete = 'Enlever les fichiers sélectionnés';
$html_attach_none = 'Vous devez sélectionner un fichier à attacher !';
$html_sort_by = 'Trier par';
$html_sort = 'Trier';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Sujet';
$html_subject_label = 'Objet :';
$html_date = 'Date';
$html_date_label = 'Date :';
$html_sent_label = 'Envoyé le :';
$html_wrote = 'a écrit';
$html_quote_wrote = 'Le %1$s à %2$s, %3$s a écrit :';
$html_size = 'Taille';
$html_totalsize = 'Taille totale';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichier';
$html_to = 'À';
$html_to_label = 'À :';
$html_cc = 'Copie';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Copie cachée :';
$html_nosubject = 'Aucun sujet';
$html_send = 'Envoyer';
$html_cancel = 'Annuler';
$html_no_mail = 'Aucun message.';
$html_logout = 'Déconnexion';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Le serveur n\'est pas correctement configuré';
$html_priority = 'Priorité';
$html_priority_label = 'Priorité :';
$html_lowest = 'Minimale';
$html_low = 'Basse';
$html_normal = 'Normale';
$html_high = 'Haute';
$html_highest = 'Maximale';
$html_flagged = 'Marqué';
$html_spam = 'Spam';
$html_spam_warning = 'Ce message a été classé comme spam.';
$html_receipt = 'Accusé de réception';
$html_select = 'Sélectionner';
$html_select_all = 'Inverser la sélection';
$html_select_contacts = 'Sélectionner des contatcs';
$html_loading_image = 'Chargement de l\'image';
$html_send_confirmed = 'Votre message a bien été envoyé';
$html_no_sendaction = 'Aucune action spécifiée. Essayer d\'activer JavaScript';
$html_error_occurred = 'Une erreur est survenue';
$html_prefs_file_error = 'Impossible d\'ouvrir le fichier de préférences';
$html_wrap = 'Tronquer les messages sortant à :';
$html_wrap_none = 'Pas de troncature';
$html_usenet_separator = 'Séparateur Usenet (« -- \n ») avant la signature';
$html_mark_as = 'Marquer comme';
$html_read = 'lu';
$html_unread = 'non lu';
$html_encoding_label = 'Encodage du texte :';
$html_add = 'Ajouter';
$html_contacts = 'Contacts de %1$s';
$html_modify = 'Modifier';
$html_back = 'Arrière';
$html_contact_add = 'Ajouter un nouveau contact';
$html_contact_mod = 'Modifier un contact';
$html_contact_first = 'Prénom';
$html_contact_last = 'Nom de famille';
$html_contact_nick = 'Pseudo';
$html_contact_mail = 'Courriel';
$html_contact_list = 'Liste de contacts de %1$s';
$html_contact_del = 'de la liste de contacts';
$html_contact_count = '%1$d contacts';
$html_contact_err1 = 'Le nombre maximal de contacts est « %1$d »';
$html_contact_err2 = 'Vous ne pouvez pas ajouter un nouveau contact';
$html_contact_err3 = 'Vous n\'avez pas le droit d\'accéder à la liste de contacts';
$html_contact_none = 'Aucun contact n\'a été trouvé';
$html_del_msg = 'Supprimer les messages sélectionnés ?';
$html_down_mail = 'Télécharger';
$original_msg = '-- Message original --';
$to_empty = 'Le champ « À » ne doit pas être vide !';
$html_images_warning = 'Pour votre sécurité, les images distantes sont désactivées.';
$html_images_display = 'Afficher les images';
$html_smtp_error_no_conn = 'Impossible d\'ouvrir la connexion';
$html_smtp_error_unexpected = 'Réponse inattendue :';
$lang_could_not_connect = 'Impossible de se connecter au serveur';
$lang_invalid_msg_num = 'Mauvais numéro de message';
$html_file_upload_attack = 'Possibilité d\'attaque depuis le fichier uploadé';
$html_invalid_email_address = 'Adresse courriel invalide';
$html_invalid_msg_per_page = 'Nombre de messages par page invalide';
$html_invalid_wrap_msg = 'Valeur de troncature invalide';
$html_seperate_msg_win = 'Messages dans des fenêtres séparées';
$html_err_file_contacts = 'Impossible d\'ouvrir le fichier des contacts';
$html_session_file_error = 'Impossible d\'ouvrir le fichier des sessions';
$html_login_not_allowed = 'Cet identifiant n\'est pas autorisé à se connecter.';
$lang_err_send_delay = 'Vous devez attendre entre deux messages (%1$d secondes)';
$html_search = 'Rechercher';
$html_new_session = 'Prochaine session';
$html_fd_filename = 'Télécharger %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Il n’y a aucun courriel|1=Il y a %1$d courriel|Il y a %1$d courriels}} dans le dossier.';
$html_fd_mailskip = 'Les courriels suivants ne feront pas partie du fichier mbox, car ils dépassent la valeur de memory_limit de PHP :';
$html_fd_filesize = 'taille %1$d';
$html_fd_skipcount = 'avec %1$d courriels';
$html_fd_largefolder = 'Selon votre vitesse de téléchargement, ce téléchargement peut échouer à cause d’un dépassement de durée du script.<br />Veuillez vérifier la complétude de votre téléchargement ou fixer max_execution_time à une valeur supérieure dans php.ini.';
$reset_clicked = 'Voulez-vous vraiment vider ce formulaire ?';
$html_send_recover = 'Connexion pour récupérer le brouillon perdu !';
$html_send_discard = 'Cliquer ici pour ignorer le brouillon enregistré.';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/fr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fr.php 2665 2016-06-22 14:49:54Z siebrand $
 */
/** French (français)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Gomoko
 * @author Hashar
 * @author IAlex
 * @author Od1n
 * @author Peter17
 * @author Sherbrooke
 * @author Verdy p
 * @author Wladek92
 */

$lang_locale = 'fr_FR.UTF-8';
$default_date_format = '%A %d %B %Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M';
$err_user_empty = 'Vous n\'avez pas saisi de nom d\'utilisateur';
$err_passwd_empty = 'Vous n\'avez pas saisi de mot de passe';
$alt_delete = 'Effacer les messages sélectionnés';
$alt_delete_one = 'Effacer le message';
$alt_new_msg = 'Nouveaux messages';
$alt_reply = 'Répondre à l\'auteur';
$alt_reply_all = 'Répondre à tous';
$alt_forward = 'Transférer';
$alt_next = 'Suivant';
$alt_prev = 'Précédent';
$title_next_page = 'Page suivante';
$title_prev_page = 'Page précédente';
$title_next_msg = 'Message suivant';
$title_prev_msg = 'Message précédent';
$html_theme_label = 'Thème :';
$html_welcome = 'Bienvenue à %1$s';
$html_login = 'Se connecter';
$html_user_label = 'Utilisateur :';
$html_passwd_label = 'Mot de passe :';
$html_submit = 'Soumettre';
$html_help = 'Aide';
$html_server_label = 'Serveur :';
$html_wrong = 'L\'identifiant ou le mot de passe ne sont pas valides';
$html_retry = 'Réessayer';
$html_remember = 'Se souvenir de moi';
$html_lang_label = 'Langue :';
$html_msgperpage_label = 'Messages par page :';
$html_preferences = 'Préférences';
$html_full_name_label = 'Nom complet :';
$html_email_address_label = 'Adresse de courriel :';
$html_bccself = 'Recevoir une copie cachée';
$html_hide_addresses = 'Cacher les adresses de courriel';
$html_outlook_quoting = 'Citation de style Outlook';
$html_reply_to = 'Répondre à';
$html_reply_to_label = 'Répondre à:';
$html_use_signature = 'Utiliser la signature';
$html_signature = 'Signature';
$html_signature_label = 'Signature :';
$html_reply_leadin_label = 'Entête de réponse :';
$html_prefs_updated = 'Les préférences ont été mises à jour';
$html_manage_folders_link = 'Gestion des dossiers IMAP';
$html_manage_filters_link = 'Gestion des filtres d\'adresses de courriel';
$html_use_graphical_smilies = 'Utiliser les émoticones graphiques';
$html_sent_folder_label = 'Copier les courriels envoyés dans un dossier dédié :';
$html_trash_folder_label = 'Déplacer les courriels effacés dans un dossier dédié :';
$html_colored_quotes = 'Citations colorées';
$html_display_struct = 'Afficher le texte structuré';
$html_send_html_mail = 'Envoyer les courriels au format HTML';
$html_folders = 'Dossiers';
$html_folders_create_failed = 'Le dossier n\'a pas pu être créé !';
$html_folders_sub_failed = 'Impossible de s\'inscrire au dossier !';
$html_folders_unsub_failed = 'Impossible de se désinscrire du dossier !';
$html_folders_rename_failed = 'Le dossier n\'a pas pu être renommé !';
$html_folders_updated = 'Dossiers mis à jour';
$html_folder_subscribe = 'S\'inscrire à';
$html_folder_rename = 'Renommer';
$html_folder_create = 'Créer un nouveau dossier appelé';
$html_folder_remove = 'Se désinscrire de';
$html_folder_delete = 'Supprimer';
$html_folder_to = 'vers';
$html_filter_remove = 'Supprimer';
$html_filter_body = 'Corps du message';
$html_filter_subject = 'Objet du message';
$html_filter_to = 'Champ A';
$html_filter_cc = 'Champs Cc';
$html_filter_from = 'Champs De';
$html_filter_change_tip = 'Pour changer un filtre, réécrivez simplement dessus.';
$html_reapply_filters = 'Réappliquer tous les filtres';
$html_filter_contains = 'contient';
$html_filter_name = 'Nom du filtre';
$html_filter_action = 'Action de filtrage';
$html_filter_moveto = 'déplacer vers';
$html_select_one = '--Sélectionner--';
$html_and = 'Et';
$html_new_msg_in = 'Nouveaux messages dans';
$html_or = 'ou';
$html_move = 'Déplacer';
$html_copy = 'Copier';
$html_messages_to = 'les messages sélectionnés vers';
$html_gotopage = 'Aller à la page';
$html_gotofolder = 'Aller au dossier';
$html_other_folders = 'Liste des dossiers';
$html_page = 'Page';
$html_of = 'sur';
$html_view_header = 'Voir l\'entête';
$html_remove_header = 'Masquer l\'entête';
$html_inbox = 'Boîte de réception';
$html_new_msg = 'Ecrire';
$html_reply = 'Répondre';
$html_reply_short = 'Re :';
$html_reply_all = 'Répondre à tous';
$html_forward = 'Transférer';
$html_forward_short = 'Tr :';
$html_forward_info = 'Le message transféré sera envoyé en pièce jointe avec ce message.';
$html_delete = 'Supprimer';
$html_new = 'Nouveau';
$html_mark = 'Effacer';
$html_att_label = 'Pièce jointe :';
$html_atts_label = 'Pièces jointes :';
$html_unknown = '[inconnu]';
$html_part_x = 'Partie %s';
$html_attach = 'Attacher';
$html_attach_forget = 'Vous devez attacher votre fichier avant d\'envoyer votre message !';
$html_attach_delete = 'Enlever les fichiers sélectionnés';
$html_attach_none = 'Vous devez sélectionner un fichier à attacher !';
$html_sort_by = 'Trier par';
$html_sort = 'Trier';
$html_from = 'De';
$html_from_label = 'De :';
$html_subject = 'Sujet';
$html_subject_label = 'Objet :';
$html_date = 'Date';
$html_date_label = 'Date :';
$html_sent_label = 'Envoyé le :';
$html_wrote = 'a écrit';
$html_quote_wrote = 'Le %1$s à %2$s, %3$s a écrit :';
$html_size = 'Taille';
$html_totalsize = 'Taille totale';
$html_kb = 'ko';
$html_mb = 'Mo';
$html_gb = 'Go';
$html_bytes = 'octets';
$html_filename = 'Fichier';
$html_to = 'À';
$html_to_label = 'À :';
$html_cc = 'Copie';
$html_cc_label = 'Cc :';
$html_bcc_label = 'Copie cachée :';
$html_nosubject = 'Aucun sujet';
$html_send = 'Envoyer';
$html_cancel = 'Annuler';
$html_no_mail = 'Aucun message.';
$html_logout = 'Déconnexion';
$html_msg = 'Message';
$html_msgs = 'Messages';
$html_configuration = 'Le serveur n\'est pas correctement configuré';
$html_priority = 'Priorité';
$html_priority_label = 'Priorité :';
$html_lowest = 'Minimale';
$html_low = 'Basse';
$html_normal = 'Normale';
$html_high = 'Haute';
$html_highest = 'Maximale';
$html_flagged = 'Marqué';
$html_spam = 'Pourriel';
$html_spam_warning = 'Ce message a été classé comme spam.';
$html_receipt = 'Accusé de réception';
$html_select = 'Sélectionner';
$html_select_all = 'Inverser la sélection';
$html_select_contacts = 'Sélectionner des contatcs';
$html_loading_image = 'Chargement de l\'image';
$html_send_confirmed = 'Votre courriel a été accepté pour être envoyé';
$html_no_sendaction = 'Aucune action spécifiée. Essayer d\'activer JavaScript';
$html_error_occurred = 'Une erreur est survenue';
$html_prefs_file_error = 'Impossible d\'ouvrir le fichier de préférences';
$html_wrap = 'Tronquer les messages sortant à :';
$html_wrap_none = 'Pas de troncature';
$html_usenet_separator = 'Séparateur Usenet (« -- \n ») avant la signature';
$html_mark_as = 'Marquer comme';
$html_read = 'lu';
$html_unread = 'non lu';
$html_encoding_label = 'Encodage du texte :';
$html_add = 'Ajouter';
$html_contacts = 'Contacts de %1$s';
$html_modify = 'Modifier';
$html_back = 'Arrière';
$html_contact_add = 'Ajouter un nouveau contact';
$html_contact_mod = 'Modifier un contact';
$html_contact_first = 'Prénom';
$html_contact_last = 'Nom de famille';
$html_contact_nick = 'Pseudo';
$html_contact_mail = 'Courriel';
$html_contact_list = 'Liste de contacts de %1$s';
$html_contact_del = 'de la liste de contacts';
$html_contact_count = '%1$d contacts';
$html_contact_err1 = 'Le nombre maximal de contacts est « %1$d »';
$html_contact_err2 = 'Vous ne pouvez pas ajouter un nouveau contact';
$html_contact_err3 = 'Vous n\'avez pas le droit d\'accéder à la liste de contacts';
$html_contact_none = 'Aucun contact n\'a été trouvé';
$html_contact_ruler_top = 'Haut';
$html_contact_listcheck_title = 'Cocher pour ajouter le courriel à la liste.';
$html_contact_list_add = 'Ajouter à la liste';
$html_contact_listname = 'Nom de la liste';
$html_contact_listonly = 'Listes uniquement';
$html_contact_all = 'Afficher tout';
$html_contact_add_confirm = 'Ajouter les courriels à la liste existante ?';
$html_del_msg = 'Supprimer les messages sélectionnés ?';
$html_down_mail = 'Télécharger';
$original_msg = '-- Message original --';
$to_empty = 'Le champ « À » ne doit pas être vide !';
$html_images_warning = 'Pour votre sécurité, les images distantes sont désactivées.';
$html_images_display = 'Afficher les images';
$html_smtp_error_no_conn = 'Impossible d\'ouvrir la connexion SMTP';
$html_smtp_error_unexpected = 'Réponse SMTP inattendue :';
$lang_could_not_connect = 'Impossible de se connecter au serveur';
$lang_invalid_msg_num = 'Mauvais numéro de message';
$html_file_upload_attack = 'Possibilité d\'attaque par fichier téléversé';
$html_invalid_email_address = 'Adresse courriel invalide';
$html_invalid_msg_per_page = 'Nombre de messages par page invalide';
$html_invalid_wrap_msg = 'Valeur de troncature invalide';
$html_seperate_msg_win = 'Messages dans des fenêtres séparées';
$html_err_file_contacts = 'Impossible d\'ouvrir le fichier des contacts en écriture .';
$html_session_file_error = 'Impossible d\'ouvrir le fichier des sessions en écriture .';
$html_login_not_allowed = 'Cet identifiant n\'est pas autorisé à se connecter.';
$lang_err_send_delay = 'Vous devez attendre entre deux courriels (%1$d secondes)';
$html_search = 'Rechercher';
$html_new_session = 'Prochaine session';
$html_fd_filename = 'Télécharger %1$s';
$html_fd_mailcount = '{{PLURAL:$1|0=Il n’y a aucun courriel|1=Il y a %1$d courriel|Il y a %1$d courriels}} dans le dossier.';
$html_fd_mailskip = 'Les courriels suivants ne feront pas partie du fichier mbox, car ils dépassent la valeur de memory_limit de PHP :';
$html_fd_filesize = 'taille %1$d';
$html_fd_skipcount = 'avec %1$d courriels';
$html_fd_largefolder = 'Selon votre vitesse de téléchargement, ce téléchargement peut échouer à cause d’un dépassement de durée d\'exécution du script.<br />Veuillez vérifier si votre téléchargement est complet ou fixer max_execution_time à une valeur supérieure dans php.ini.';
$reset_clicked = 'Voulez-vous vraiment vider ce formulaire ?';
$html_send_recover = 'Connexion pour récupérer le brouillon perdu !';
$html_send_discard = 'Cliquer ici pour ignorer le brouillon enregistré.';
$html_collect_label = 'Collecter automatiquement les adresses de courriel :';
$html_collect_option0 = 'Jamais';
$html_collect_option1 = 'Seulement pour les courriels sortants';
$html_collect_option2 = 'Seulement pour les courriels ouverts';
$html_collect_option3 = 'Toujours';
